@@ -89,8 +89,7 @@ This function is used as a callback for a channel button."
 	(point (point))
 	window)
     (unwind-protect
-	(save-excursion
-	  (set-buffer (riece-event-buffer event))
+	(with-current-buffer (riece-event-buffer event)
 	  (goto-char (riece-event-point event))
 	  (widget-button-click event))
       ;; riece-button-switch-to-identity changes window-configuration
@@ -106,8 +105,7 @@ This function is used as a callback for a channel button."
 (defun riece-identity-button-popup-menu (event)
   "Popup the menu for identity buttons."
   (interactive "e")
-  (save-excursion
-    (set-buffer (riece-event-buffer event))
+  (with-current-buffer (riece-event-buffer event)
     (goto-char (riece-event-point event))
     (riece-popup-menu-popup
      (if (riece-channel-p (riece-identity-prefix
