@@ -19,8 +19,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Code:
 
@@ -32,6 +32,7 @@
 (require 'riece-server)
 (require 'riece-user)
 (require 'riece-mode)
+(require 'riece-cache)
 
 (defun riece-get-buffer-create (name &optional init-major-mode)
   (let ((buffer (get-buffer name)))
@@ -65,8 +66,7 @@
     (setq buffers (list buffers)))
   (while buffers
     (run-hooks 'riece-before-insert-functions)
-    (save-excursion
-      (set-buffer (car buffers))
+    (with-current-buffer (car buffers)
       (let ((inhibit-read-only t)
 	    buffer-read-only
 	    (start (goto-char (point-max)))
@@ -221,7 +221,7 @@
 	 (setq identities
 	       (cons (riece-make-identity (symbol-name user) server-name)
 		     identities)))
-       riece-user-obarray)
+       (riece-cache-hash-obarray riece-user-cache))
       identities)))
 
 (defun riece-get-channels-on-server (server-name)
@@ -232,7 +232,7 @@
 	 (setq identities
 	       (cons (riece-make-identity (symbol-name channel) server-name)
 		     identities)))
-       riece-channel-obarray)
+       (riece-cache-hash-obarray riece-channel-cache))
       identities)))
 
 (defun riece-get-identities-on-server (server-name)
